@@ -50,7 +50,7 @@
 #' @author Justin Esarey and Jane Lawrence Sumner
 #' @references Benjamini, Yoav, and Yosef Hochberg. 1995. "Controlling the False Discovery Rate: A Practical and Powerful Approach to Multiple Testing." \emph{Journal of the Royal Statistical Society, Series B} 57(1): 289-300.
 #' @references Clark, William R., and Matt Golder. 2006. "Rehabilitating Duverger's Theory." \emph{Comparative Political Studies} 39(6): 679-708.
-#' @references Esarey, Justin, and Jane Lawrence Sumner. 2017. "Marginal Effects in Interaction Models: Determining and Controlling the False Positive Rate." URL: http://jee3.web.rice.edu/interaction-overconfidence.pdf.
+#' @references Esarey, Justin, and Jane Lawrence Sumner. 2017. "Marginal Effects in Interaction Models: Determining and Controlling the False Positive Rate." URL: <http://justinesarey.com/interaction-overconfidence.pdf>.
 #' @importFrom stats pt qt
 #' @export
 
@@ -76,6 +76,8 @@ fdrInteraction <- function(me.vec, me.sd.vec, df, level=0.95){
     
   }
   
+  if(i==1){cat("Note: hit end of process w/o detecting statistically significant relationship", "\n", "\n")}
+  
   critical.t <- abs( qt(multiplier[i]*(alpha/2), df) )
   return(critical.t)
   
